/*
 * This file is part of PySide: Python for Qt
 *
 * Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
 *
 * Contact: PySide team <contact@pyside.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * version 2.1 as published by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */



#ifndef SBK_QTWEBENGINEWIDGETS_PYTHON_H
#define SBK_QTWEBENGINEWIDGETS_PYTHON_H

#include <sbkpython.h>
#include <conversions.h>
#include <sbkenum.h>
#include <basewrapper.h>
#include <bindingmanager.h>
#include <memory>

#include <pysidesignal.h>
// Module Includes
#include <pyside2_qtcore_python.h>
#include <pyside2_qtgui_python.h>
#include <pyside2_qtwidgets_python.h>
#include <pyside2_qtnetwork_python.h>

// Binded library includes
#include <qwebenginehistory.h>
#include <qwebenginepage.h>
#include <qwebenginedownloaditem.h>
#include <qwebengineprofile.h>
#include <qwebengineview.h>
#include <qwebenginecertificateerror.h>
#include <qwebenginescript.h>
// Conversion Includes - Primitive Types
#include <QStringList>
#include <QString>
#include <wtypes.h>
#include <signalmanager.h>
#include <typeresolver.h>
#include <qabstractitemmodel.h>

// Conversion Includes - Container Types
#include <QQueue>
#include <QSet>
#include <QStack>
#include <QMap>
#include <pysideconversions.h>
#include <QList>
#include <QVector>
#include <QMultiMap>
#include <QPair>
#include <QLinkedList>

// Type indices
#define SBK_QWEBENGINESCRIPT_IDX                                     18
#define SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX                      19
#define SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX                       20
#define SBK_QWEBENGINEHISTORYITEM_IDX                                5
#define SBK_QWEBENGINECERTIFICATEERROR_IDX                           1
#define SBK_QWEBENGINECERTIFICATEERROR_ERROR_IDX                     2
#define SBK_QWEBENGINEDOWNLOADITEM_IDX                               3
#define SBK_QWEBENGINEDOWNLOADITEM_DOWNLOADSTATE_IDX                 4
#define SBK_QWEBENGINEPROFILE_IDX                                    15
#define SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX                      16
#define SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX            17
#define SBK_QWEBENGINEVIEW_IDX                                       21
#define SBK_QWEBENGINEPAGE_IDX                                       6
#define SBK_QWEBENGINEPAGE_WEBACTION_IDX                             13
#define SBK_QWEBENGINEPAGE_FINDFLAG_IDX                              9
#define SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG__IDX                      0
#define SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX                         14
#define SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX                      12
#define SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX                        11
#define SBK_QWEBENGINEPAGE_FEATURE_IDX                               7
#define SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX                     8
#define SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX         10
#define SBK_QtWebEngineWidgets_IDX_COUNT                             22

// This variable stores all Python types exported by this module.
extern PyTypeObject** SbkPySide2_QtWebEngineWidgetsTypes;

// This variable stores all type converters exported by this module.
extern SbkConverter** SbkPySide2_QtWebEngineWidgetsTypeConverters;

// Converter indices
#define SBK_QTWEBENGINEWIDGETS_QLIST_QOBJECTPTR_IDX                  0 // const QList<QObject * > &
#define SBK_QTWEBENGINEWIDGETS_QLIST_QBYTEARRAY_IDX                  1 // QList<QByteArray >
#define SBK_QTWEBENGINEWIDGETS_QLIST_QURL_IDX                        2 // const QList<QUrl > &
#define SBK_QTWEBENGINEWIDGETS_QLIST_QACTIONPTR_IDX                  3 // QList<QAction * >
#define SBK_QTWEBENGINEWIDGETS_QLIST_QVARIANT_IDX                    4 // QList<QVariant >
#define SBK_QTWEBENGINEWIDGETS_QLIST_QSTRING_IDX                     5 // QList<QString >
#define SBK_QTWEBENGINEWIDGETS_QMAP_QSTRING_QVARIANT_IDX             6 // QMap<QString, QVariant >
#define SBK_QtWebEngineWidgets_CONVERTERS_IDX_COUNT                  7

// Macros for type check

namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject* SbkType< ::QWebEngineScript::InjectionPoint >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineScript::ScriptWorldId >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineScript >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINESCRIPT_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEngineHistoryItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEHISTORYITEM_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEngineCertificateError::Error >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINECERTIFICATEERROR_ERROR_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineCertificateError >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINECERTIFICATEERROR_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEngineDownloadItem::DownloadState >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEDOWNLOADITEM_DOWNLOADSTATE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineDownloadItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEDOWNLOADITEM_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEngineProfile::HttpCacheType >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineProfile::PersistentCookiesPolicy >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEngineProfile >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPROFILE_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEngineView >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEVIEW_IDX]); }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::WebAction >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBACTION_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::FindFlag >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FINDFLAG_IDX]; }
template<> inline PyTypeObject* SbkType< ::QFlags<QWebEnginePage::FindFlag> >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG__IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::WebWindowType >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::PermissionPolicy >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::NavigationType >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::Feature >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FEATURE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::FileSelectionMode >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage::JavaScriptConsoleMessageLevel >() { return SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX]; }
template<> inline PyTypeObject* SbkType< ::QWebEnginePage >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtWebEngineWidgetsTypes[SBK_QWEBENGINEPAGE_IDX]); }

} // namespace Shiboken

#endif // SBK_QTWEBENGINEWIDGETS_PYTHON_H

